-- Tour Guide - Trade Skill settings and handler
TGTradeS = {}
TGTradeS.ProList = {"Alchemy", "Archaeology", "Blacksmithing", "Cooking", "Enchanting", "Engineering", "First Aid", "Inscription", "Jewelcrafting", "Leatherworking", "Mining", "Tailoring", "UnknownRecipe"}
local frame, events = CreateFrame("Frame"), {};

-- Fire this script when Tour Guide - Trade Skill addon is loaded
function events:ADDON_LOADED(addon)
  if (addon == "TourGuide-Tradeskill") then
    self:UnregisterEvent("ADDON_LOADED")

    -- Setup DB default values
    local defaults = {
      -- Config Settings that can be shared with other profiles
      ["profile"] = {
        ["Config"] = {
          ["LureAlert"] = true,
          ["AutoBuy"] = false,
          ["AutoLearn"] = false,
          ["AutoTrain"] = false,
        },
      },

      -- Character Specific DB
      ["char"] = {
        ["atmerchant"] = false,
        ["attrainer"] = false,
        ["guide"] = "No Guide",
        ["UnknownRecipe"] = {},
      },
    }

    -- Setup DB
    TGTradeS.db = LibStub("AceDB-3.0"):New("TradeSkillDB", defaults)

    -- Setup Currency
    TGTradeS.currency = {
      ["Dalaran Jewelcrafting Token"]      = 61,
      ["Dalaran Cooking Award"]            = 81,
      ["Champion's Seal"]                  = 241,
      ["Illustrious Jewelcrafter's Token"] = 361,
      ["Conquest Points"]                  = 390,
      ["Tol Barad Commendation"]           = 391,
      ["Honor Points"]                     = 392,
      ["Justice Points"]                   = 395,
      ["Valor Points"]                     = 396,
      ["Chef's Award"]                     = 402,
    }
    -- Setup fix for profession names for profession trainers
    TGTradeS.proTrainName = {
      ["Alchemy"]        = "Alchemist",
      ["Archaeology"]    = "Archaeology",
      ["Blacksmithing"]  = "Blacksmith",
      ["Cooking"]        = "Cook",
      ["Enchanting"]     = "Enchanter",
      ["Engineering"]    = "Engineer",
      ["First Aid"]      = "First Aid",
      ["Fishing"]        = "Fishing",
      ["Herbalism"]      = "Herbalist",
      ["Inscription"]    = "Scribe",
      ["Jewelcrafting"]  = "Jewelcrafter",
      ["Leatherworking"] = "Leatherworker",
      ["Mining"]         = "Miner",
      ["Skinning"]       = "Skinner",
      ["Tailoring"]      = "Tailor",
    }
    -- Setup fix for profession training level name
    TGTradeS.proTrainNameLevel = {
       [75] = "Apprentice",
      [150] = "Journeyman",
      [225] = "Expert",
      [300] = "Artisan",
      [375] = "Master",
      [450] = "Grand Master",
      [525] = "Illustrious Grand Master",
    }

    -- Fix atmerchant if ui reloaded
    if TGTradeS.db.char.atmerchant then TGTradeS.db.char.atmerchant = false end

    -- Fix attrainer if ui reloaded
    if TGTradeS.db.char.attrainer then TGTradeS.db.char.attrainer = false end

    -- Fire Functions
    TGTradeS:Cleanup()
    TGTradeS:Config()

    -- Print out that the addon is loaded
    print("TourGuide - Trade Skill: Loaded");
  end
end

-- Update Recipe Saved list
function events:TRADE_SKILL_SHOW()
  local tradeskillName, _, _  = GetTradeSkillLine()
  TGTradeS:UPDATESKILLLIST(tradeskillName)
end

-- Auto Buy From Merchant
function events:MERCHANT_SHOW()
  -- check if you can auto buy stuff from merchant
  if TourGuide.tags[TourGuide.current]:match("|LOOT|(%d+)%s?(%d*)|") then
    TGTradeS:AutoBuyFromMerchant()
  end
  TGTradeS.db.char.atmerchant = true
end

-- Auto Buy From Merchant
function events:MERCHANT_CLOSED()
  TGTradeS.db.char.atmerchant = false
end

-- Auto Buy From Merchant
function events:TRAINER_SHOW()
  -- check if the trainer can auto train you
  if TourGuide.tags[TourGuide.current]:match("|TRAINSKILL|([%a:'%s]+)%s?(%d+)|") then
    TGTradeS:AutoTrainFromTrainer()
  end
  -- check if the trainer can auto learn you
  if TourGuide.tags[TourGuide.current]:match("|LEARNITEM|([%a:'%s]+)|") then
    TGTradeS:AutoLearnFromTrainer()
  end
  TGTradeS.db.char.attrainer = true
end

-- Auto Buy From Merchant
function events:TRAINER_CLOSED()
  TGTradeS.db.char.attrainer = false
end

frame:SetScript("OnEvent",
  function(self, event, ...)
    events[event](self, ...)
  end
)

for k, v in pairs(events) do
  frame:RegisterEvent(k)
end